xsdata.codegen.handlers package
===============================

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.codegen.handlers.attribute_enum_union
   xsdata.codegen.handlers.attribute_group
   xsdata.codegen.handlers.attribute_implied
   xsdata.codegen.handlers.attribute_merge
   xsdata.codegen.handlers.attribute_mismatch
   xsdata.codegen.handlers.attribute_substitution
   xsdata.codegen.handlers.attribute_type
   xsdata.codegen.handlers.class_extension

Module contents
---------------

.. automodule:: xsdata.codegen.handlers
   :members:
   :undoc-members:
   :show-inheritance:
